KeyVerificationAdmin_MessageType class

Three stages of this request.

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

valueOf(int value) → KeyVerificationAdmin_MessageType?

Constants

DO_NOT_VERIFY → const KeyVerificationAdmin_MessageType
This is the cancel path, can be taken at any point
DO_VERIFY → const KeyVerificationAdmin_MessageType
Once the user has compared the verification message, this message notifies the node.
INITIATE_VERIFICATION → const KeyVerificationAdmin_MessageType
This is the first stage, where a client initiates
PROVIDE_SECURITY_NUMBER → const KeyVerificationAdmin_MessageType
After the nonce has been returned over the mesh, the client prompts for the security number And uses this message to provide it to the node.
values → const List<KeyVerificationAdmin_MessageType>