Config_DeviceConfig_BuzzerMode class

Defines buzzer behavior for audio feedback

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

valueOf(int value) → Config_DeviceConfig_BuzzerMode?

Constants

ALL_ENABLED → const Config_DeviceConfig_BuzzerMode
Default behavior. Buzzer is enabled for all audio feedback including button presses and alerts.
DIRECT_MSG_ONLY → const Config_DeviceConfig_BuzzerMode
Direct Message notifications only. Buzzer is enabled only for direct messages and alerts, but not for button presses. External notification config determines the specifics of the notification behavior.
DISABLED → const Config_DeviceConfig_BuzzerMode
Disabled. All buzzer audio feedback is disabled.
NOTIFICATIONS_ONLY → const Config_DeviceConfig_BuzzerMode
Notifications Only. Buzzer is enabled only for notifications and alerts, but not for button presses. External notification config determines the specifics of the notification behavior.
SYSTEM_ONLY → const Config_DeviceConfig_BuzzerMode
Non-notification system buzzer tones only. Buzzer is enabled only for non-notification tones such as button presses, startup, shutdown, but not for alerts.
values → const List<Config_DeviceConfig_BuzzerMode>