Config_DisplayConfig_GpsCoordinateFormat class

How the GPS coordinates are displayed on the OLED screen.

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

DEC → const Config_DisplayConfig_GpsCoordinateFormat
GPS coordinates are displayed in the normal decimal degrees format: DD.DDDDDD DDD.DDDDDD
DMS → const Config_DisplayConfig_GpsCoordinateFormat
GPS coordinates are displayed in the degrees minutes seconds format: DD°MM'SS"C DDD°MM'SS"C, where C is the compass point representing the locations quadrant
MGRS → const Config_DisplayConfig_GpsCoordinateFormat
Military Grid Reference System format: ZZB CD EEEEE NNNNN, where Z is zone, B is band, C is the east 100k square, D is the north 100k square, E is easting, N is northing
OLC → const Config_DisplayConfig_GpsCoordinateFormat
Open Location Code (aka Plus Codes).
OSGR → const Config_DisplayConfig_GpsCoordinateFormat
Ordnance Survey Grid Reference (the National Grid System of the UK). Format: AB EEEEE NNNNN, where A is the east 100k square, B is the north 100k square, E is the easting, N is the northing
UTM → const Config_DisplayConfig_GpsCoordinateFormat
Universal Transverse Mercator format: ZZB EEEEEE NNNNNNN, where Z is zone, B is band, E is easting, N is northing
values → const List<Config_DisplayConfig_GpsCoordinateFormat>