Config_LoRaConfig_ModemPreset class

Standard predefined channel settings Note: these mappings must match ModemPreset Choice in the device code.

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

valueOf(int value) → Config_LoRaConfig_ModemPreset?

Constants

LONG_FAST → const Config_LoRaConfig_ModemPreset
Long Range - Fast
LONG_MODERATE → const Config_LoRaConfig_ModemPreset
Long Range - Moderately Fast
LONG_SLOW → const Config_LoRaConfig_ModemPreset
Long Range - Slow
MEDIUM_FAST → const Config_LoRaConfig_ModemPreset
Medium Range - Fast
MEDIUM_SLOW → const Config_LoRaConfig_ModemPreset
Medium Range - Slow
SHORT_FAST → const Config_LoRaConfig_ModemPreset
Short Range - Fast
SHORT_SLOW → const Config_LoRaConfig_ModemPreset
Short Range - Slow
SHORT_TURBO → const Config_LoRaConfig_ModemPreset
Short Range - Turbo This is the fastest preset and the only one with 500kHz bandwidth. It is not legal to use in all regions due to this wider bandwidth.
values → const List<Config_LoRaConfig_ModemPreset>
VERY_LONG_SLOW → const Config_LoRaConfig_ModemPreset
Very Long Range - Slow Deprecated in 2.5: Works only with txco and is unusably slow