Config_NetworkConfig_ProtocolFlags class

Available flags auxiliary network protocols

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

valueOf(int value) → Config_NetworkConfig_ProtocolFlags?

Constants

NO_BROADCAST → const Config_NetworkConfig_ProtocolFlags
Do not broadcast packets over any network protocol
UDP_BROADCAST → const Config_NetworkConfig_ProtocolFlags
Enable broadcasting packets via UDP over the local network
values → const List<Config_NetworkConfig_ProtocolFlags>