FirmwareEdition class

Enum to indicate to clients whether this firmware is a special firmware build, like an event. The first 16 values are reserved for non-event special firmwares, like the Smart Citizen use case.

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

valueOf(int value) → FirmwareEdition?

Constants

BURNING_MAN → const FirmwareEdition
Burning Man, the yearly hippie gathering in the desert
DEFCON → const FirmwareEdition
DEFCON, the yearly hacker conference
DIY_EDITION → const FirmwareEdition
Placeholder for DIY and unofficial events
HAMVENTION → const FirmwareEdition
Hamvention, the Dayton amateur radio convention
OPEN_SAUCE → const FirmwareEdition
Open Sauce, the maker conference held yearly in CA
SMART_CITIZEN → const FirmwareEdition
Firmware for use in the Smart Citizen environmental monitoring network
values → const List<FirmwareEdition>
VANILLA → const FirmwareEdition
Vanilla firmware