MeshPacket_TransportMechanism class

Enum to identify which transport mechanism this packet arrived over

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

valueOf(int value) → MeshPacket_TransportMechanism?

Constants

TRANSPORT_API → const MeshPacket_TransportMechanism
Arrived via API connection
TRANSPORT_INTERNAL → const MeshPacket_TransportMechanism
The default case is that the node generated a packet itself
TRANSPORT_LORA → const MeshPacket_TransportMechanism
Arrived via the primary LoRa radio
TRANSPORT_LORA_ALT1 → const MeshPacket_TransportMechanism
Arrived via a secondary LoRa radio
TRANSPORT_LORA_ALT2 → const MeshPacket_TransportMechanism
Arrived via a tertiary LoRa radio
TRANSPORT_LORA_ALT3 → const MeshPacket_TransportMechanism
Arrived via a quaternary LoRa radio
TRANSPORT_MQTT → const MeshPacket_TransportMechanism
Arrived via an MQTT connection
TRANSPORT_MULTICAST_UDP → const MeshPacket_TransportMechanism
Arrived via Multicast UDP
values → const List<MeshPacket_TransportMechanism>