Position_AltSource class

How the altitude was acquired: manual, GPS int/ext, etc Default: same as location_source if present

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

valueOf(int value) → Position_AltSource?

Constants

ALT_BAROMETRIC → const Position_AltSource
TODO: REPLACE
ALT_EXTERNAL → const Position_AltSource
TODO: REPLACE
ALT_INTERNAL → const Position_AltSource
TODO: REPLACE
ALT_MANUAL → const Position_AltSource
TODO: REPLACE
ALT_UNSET → const Position_AltSource
TODO: REPLACE
values → const List<Position_AltSource>